Enum Ckpol
#[repr(u8)]pub enum Ckpol {
Rising = 0,
Falling = 1,
Both = 2,
_RESERVED_3 = 3,
}Variants
Rising = 0
the rising edge is the active edge used for counting. If the LPTIM is configured in Encoder mode (ENC bit is set), the encoder sub-mode 1 is active.
Falling = 1
the falling edge is the active edge used for counting. If the LPTIM is configured in Encoder mode (ENC bit is set), the encoder sub-mode 2 is active.
Both = 2
both edges are active edges. When both external clock signal edges are considered active ones, the LPTIM must also be clocked by an internal clock source with a frequency equal to at least four times the external clock frequency. If the LPTIM is configured in Encoder mode (ENC bit is set), the encoder sub-mode 3 is active.
_RESERVED_3 = 3
Implementations